==> jc-1.4.0.tar.gz: soot/util/NumberedSet__24NumberedSetIterator.h <==
// class soot.util.NumberedSet$NumberedSetIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 29038b1bead22ac8 soot_util_NumberedSet__24NumberedSetIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_NumberedSet__24NumberedSetIterator_H_
#define _JC_soot_util_NumberedSet__24NumberedSetIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_util_NumberedSet$object;

// Typedefs
typedef struct _jc_soot_util_NumberedSet__24NumberedSetIterator$sub_refs	_jc_soot_util_NumberedSet__24NumberedSetIterator$sub_refs;
typedef struct _jc_soot_util_NumberedSet__24NumberedSetIterator$sub_nonrefs	_jc_soot_util_NumberedSet__24NumberedSetIterator$sub_nonrefs;
typedef struct _jc_soot_util_NumberedSet__24NumberedSetIterator$refs	_jc_soot_util_NumberedSet__24NumberedSetIterator$refs;
typedef struct _jc_soot_util_NumberedSet__24NumberedSetIterator$nonrefs	_jc_soot_util_NumberedSet__24NumberedSetIterator$nonrefs;
typedef struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object	_jc_soot_util_NumberedSet__24NumberedSetIterator$object;

typedef const struct _jc_soot_util_NumberedSet__24NumberedSetIterator$vmethods	_jc_soot_util_NumberedSet__24NumberedSetIterator$vmethods;
typedef const struct _jc_soot_util_NumberedSet__24NumberedSetIterator$vtable	_jc_soot_util_NumberedSet__24NumberedSetIterator$vtable;
typedef const struct _jc_soot_util_NumberedSet__24NumberedSetIterator$vtype	_jc_soot_util_NumberedSet__24NumberedSetIterator$vtype;

// Constructors
extern void _jc_soot_util_NumberedSet__24NumberedSetIterator$method$_init$bb89cbca9b373273(_jc_env *, struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object *, struct _jc_soot_util_NumberedSet$object *, struct _jc_soot_util_NumberedSet$object *);

// Virtual methods
extern jboolean _jc_soot_util_NumberedSet__24NumberedSetIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_util_NumberedSet__24NumberedSetIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object *);
extern void _jc_soot_util_NumberedSet__24NumberedSetIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object *);
extern void _jc_soot_util_NumberedSet__24NumberedSetIterator$method$seekNext$d7cfce2d63c0ff51(_jc_env *, struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_NumberedSet__24NumberedSetIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_util_NumberedSet__24NumberedSetIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_util_NumberedSet__24NumberedSetIterator$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_soot_util_NumberedSet__24NumberedSetIterator$method_info$seekNext$d7cfce2d63c0ff51;

// Virtual methods structure
struct _jc_soot_util_NumberedSet__24NumberedSetIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object *);
	void	(*seekNext$d7cfce2d63c0ff51)(_jc_env *, struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object *);
};

// Vtable
struct _jc_soot_util_NumberedSet__24NumberedSetIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_NumberedSet__24NumberedSetIterator$vmethods	soot_util_NumberedSet__24NumberedSetIterator;
};

// Vtype
struct _jc_soot_util_NumberedSet__24NumberedSetIterator$vtype {
	_jc_type			type;
	_jc_soot_util_NumberedSet__24NumberedSetIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_NumberedSet__24NumberedSetIterator$sub_refs {
	struct _jc_soot_util_NumberedSet$object	*set;
	struct _jc_soot_util_NumberedSet$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_util_NumberedSet__24NumberedSetIterator$refs {
    _jc_soot_util_NumberedSet__24NumberedSetIterator$sub_refs	soot_util_NumberedSet__24NumberedSetIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_NumberedSet__24NumberedSetIterator$sub_nonrefs {
	jint	cur;
};

// Non-reference instance fields (object)
struct _jc_soot_util_NumberedSet__24NumberedSetIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_NumberedSet__24NumberedSetIterator$sub_nonrefs	soot_util_NumberedSet__24NumberedSetIterator;
};

// Object instance structure
struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object {
	_jc_soot_util_NumberedSet__24NumberedSetIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_NumberedSet__24NumberedSetIterator$vtype	*vtype;
	_jc_soot_util_NumberedSet__24NumberedSetIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_NumberedSet__24NumberedSetIterator$vtype _jc_soot_util_NumberedSet__24NumberedSetIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_NumberedSet__24NumberedSetIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_NumberedSet__24NumberedSetIterator$class_object;

#endif	/* _JC_soot_util_NumberedSet__24NumberedSetIterator_H_ */

==> jc-1.4.6.tar.gz: soot/util/NumberedSet__24NumberedSetIterator.h <==
// class soot.util.NumberedSet$NumberedSetIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 29038b1bead22ac8 soot_util_NumberedSet__24NumberedSetIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_NumberedSet__24NumberedSetIterator_H_
#define _JC_soot_util_NumberedSet__24NumberedSetIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_util_NumberedSet$object;

// Typedefs
typedef struct _jc_soot_util_NumberedSet__24NumberedSetIterator$sub_refs	_jc_soot_util_NumberedSet__24NumberedSetIterator$sub_refs;
typedef struct _jc_soot_util_NumberedSet__24NumberedSetIterator$sub_nonrefs	_jc_soot_util_NumberedSet__24NumberedSetIterator$sub_nonrefs;
typedef struct _jc_soot_util_NumberedSet__24NumberedSetIterator$refs	_jc_soot_util_NumberedSet__24NumberedSetIterator$refs;
typedef struct _jc_soot_util_NumberedSet__24NumberedSetIterator$nonrefs	_jc_soot_util_NumberedSet__24NumberedSetIterator$nonrefs;
typedef struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object	_jc_soot_util_NumberedSet__24NumberedSetIterator$object;

typedef const struct _jc_soot_util_NumberedSet__24NumberedSetIterator$vmethods	_jc_soot_util_NumberedSet__24NumberedSetIterator$vmethods;
typedef const struct _jc_soot_util_NumberedSet__24NumberedSetIterator$vtable	_jc_soot_util_NumberedSet__24NumberedSetIterator$vtable;
typedef const struct _jc_soot_util_NumberedSet__24NumberedSetIterator$vtype	_jc_soot_util_NumberedSet__24NumberedSetIterator$vtype;

// Constructors
extern void _jc_soot_util_NumberedSet__24NumberedSetIterator$method$_init$bb89cbca9b373273(_jc_env *, struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object *, struct _jc_soot_util_NumberedSet$object *, struct _jc_soot_util_NumberedSet$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_util_NumberedSet__24NumberedSetIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_util_NumberedSet__24NumberedSetIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object *) _JC_JCNI_ATTR;
extern void _jc_soot_util_NumberedSet__24NumberedSetIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object *) _JC_JCNI_ATTR;
extern void _jc_soot_util_NumberedSet__24NumberedSetIterator$method$seekNext$d7cfce2d63c0ff51(_jc_env *, struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_NumberedSet__24NumberedSetIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_util_NumberedSet__24NumberedSetIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_util_NumberedSet__24NumberedSetIterator$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_soot_util_NumberedSet__24NumberedSetIterator$method_info$seekNext$d7cfce2d63c0ff51;

// Virtual methods structure
struct _jc_soot_util_NumberedSet__24NumberedSetIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object *) _JC_JCNI_ATTR;
	void	(*seekNext$d7cfce2d63c0ff51)(_jc_env *, struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_NumberedSet__24NumberedSetIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_NumberedSet__24NumberedSetIterator$vmethods	soot_util_NumberedSet__24NumberedSetIterator;
};

// Vtype
struct _jc_soot_util_NumberedSet__24NumberedSetIterator$vtype {
	_jc_type			type;
	_jc_soot_util_NumberedSet__24NumberedSetIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_NumberedSet__24NumberedSetIterator$sub_refs {
	struct _jc_soot_util_NumberedSet$object	*set;
	struct _jc_soot_util_NumberedSet$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_util_NumberedSet__24NumberedSetIterator$refs {
    _jc_soot_util_NumberedSet__24NumberedSetIterator$sub_refs	soot_util_NumberedSet__24NumberedSetIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_NumberedSet__24NumberedSetIterator$sub_nonrefs {
	jint	cur;
};

// Non-reference instance fields (object)
struct _jc_soot_util_NumberedSet__24NumberedSetIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_NumberedSet__24NumberedSetIterator$sub_nonrefs	soot_util_NumberedSet__24NumberedSetIterator;
};

// Object instance structure
struct _jc_soot_util_NumberedSet__24NumberedSetIterator$object {
	_jc_soot_util_NumberedSet__24NumberedSetIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_NumberedSet__24NumberedSetIterator$vtype	*vtype;
	_jc_soot_util_NumberedSet__24NumberedSetIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_NumberedSet__24NumberedSetIterator$vtype _jc_soot_util_NumberedSet__24NumberedSetIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_NumberedSet__24NumberedSetIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_NumberedSet__24NumberedSetIterator$class_object;

#endif	/* _JC_soot_util_NumberedSet__24NumberedSetIterator_H_ */
